import {
  pico,
  consola,
  inquirer,
  getGitRepoInfo,
  ora
} from "@mango-scripts/utils";
import { run } from "../../utils/index.mjs";
const confirmRegistry = async () => {
  const registry = (await run("npm", ["config", "get", "registry"], { stdio: "pipe" })).stdout;
  const { yes } = await inquirer.prompt([
    {
      type: "confirm",
      name: "yes",
      message: `\u5F53\u524D npm registry \u4E3A: ${pico.yellow(registry)}\uFF0C\u786E\u5B9A? `
    }
  ]);
  return yes;
};
const confirmGitBranch = async () => {
  const { branch } = getGitRepoInfo();
  const { yes } = await inquirer.prompt([
    {
      type: "confirm",
      name: "yes",
      message: `\u5F53\u524D\u53D1\u5E03\u7684\u5206\u652F\u4E3A: ${pico.yellow(branch)}\uFF0C\u786E\u5B9A\uFF1F`
    }
  ]);
  return yes;
};
const confirmWorktreeEmpty = async () => {
  const isWorktreeEmpty = !(await run("git", ["status", "--porcelain"], { stdio: "pipe" }))?.stdout;
  !isWorktreeEmpty && consola.error("\u68C0\u6D4B\u5230\u5F53\u524D\u5DE5\u4F5C\u533A\u6709\u5C1A\u672A\u63D0\u4EA4\u7684\u4EE3\u7801\uFF0C\u8BF7\u5148\u63D0\u4EA4\u4EE3\u7801");
  return isWorktreeEmpty;
};
const confirmNpmLoggedIn = async () => {
  try {
    const spinner = ora().start(`\u83B7\u53D6 npm \u767B\u5F55\u72B6\u6001...`);
    const user = (await run("npm", ["whoami"], { stdio: "pipe" })).stdout.trim();
    spinner.stop();
    if (!user) {
      consola.error("\u68C0\u6D4B\u5230\u4F60\u5C1A\u672A\u767B\u5F55 npm\uFF0C\u8BF7\u4F7F\u7528 `npm login` \u767B\u5F55\u540E\u518D\u7EE7\u7EED\u3002");
      return false;
    }
    const { yes } = await inquirer.prompt([
      {
        type: "confirm",
        name: "yes",
        message: `\u5F53\u524D\u767B\u5F55\u7684 npm \u7528\u6237\u4E3A: ${pico.cyan(user)}\uFF0C\u786E\u5B9A\uFF1F`
      }
    ]);
    return yes;
  } catch (error) {
    consola.error("\u68C0\u6D4B\u5230\u60A8\u5C1A\u672A\u767B\u5F55 npm\uFF0C\u8BF7\u4F7F\u7528 `npm login` \u767B\u5F55\u540E\u518D\u7EE7\u7EED\u3002");
    return false;
  }
};
export {
  confirmGitBranch,
  confirmNpmLoggedIn,
  confirmRegistry,
  confirmWorktreeEmpty
};
